CREATE TABLE IF NOT EXISTS real_time_formulas (
    id integer NOT NULL PRIMARY KEY AUTOINCREMENT,
    table_schema varchar(128) NULL,
    table_name varchar(128) NOT NULL,
    column_name varchar(128) NOT NULL,
    rtd_formula varchar(255) NULL,
    is_disabled smallint NULL
);

CREATE UNIQUE INDEX ix_real_time_formulas_schema_name_column_name ON real_time_formulas (table_name, column_name);


CREATE TABLE IF NOT EXISTS real_time_tables (
    id integer NOT NULL PRIMARY KEY AUTOINCREMENT,
    table_schema varchar(128) NULL,
    table_name varchar(128) NOT NULL,
    load_code varchar(2000) NULL,
    is_history smallint NULL,
    is_disabled smallint NULL,
    time_zone varchar(50) NULL,
    rtd_instance_name varchar(50) NULL
);

CREATE UNIQUE INDEX ix_realtimetables_schema_name ON real_time_tables (table_name);

CREATE TABLE IF NOT EXISTS es_stock_list (
    code varchar(50) NOT NULL,
  PRIMARY KEY (code)
);

CREATE TABLE IF NOT EXISTS es_historical_prices (
    symbol varchar(50) NOT NULL,
    date date NOT NULL,
    time time NULL,
    last double NULL,
    change double NULL,
    percent_change double NULL,
    bid double NULL,
    ask double NULL,
    bid_size integer NULL,
    ask_size integer NULL,
    open double NULL,
    high double NULL,
    low double NULL,
    volume bigint NULL,
    open_int integer NULL,
    trade_price double NULL,
    last_update_timestamp timestamp default current_timestamp,
  PRIMARY KEY (symbol, date)
);

INSERT INTO real_time_tables (table_schema, table_name, load_code, is_history, is_disabled, time_zone, rtd_instance_name) VALUES (NULL, 'es_historical_prices', 'SELECT code FROM es_stock_list', NULL, 1, 'Eastern Standard Time', NULL);

INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'es_historical_prices', 'code', NULL, NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'es_historical_prices', 'symbol', '=RTD("esrtd",,[CODE],"Symbol")', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'es_historical_prices', 'date', '=Date()', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'es_historical_prices', 'time', '=RTD("esrtd",,[CODE],"Time")', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'es_historical_prices', 'last', '=RTD("esrtd",,[CODE],"Last")', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'es_historical_prices', 'trade_price', '=RTD("esrtd",,[CODE],"TradePrice")', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'es_historical_prices', 'change', '=RTD("esrtd",,[CODE],"Change")', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'es_historical_prices', 'percent_change', '=RTD("esrtd",,[CODE],"% Change")', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'es_historical_prices', 'bid', '=RTD("esrtd",,[CODE],"Bid")', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'es_historical_prices', 'ask', '=RTD("esrtd",,[CODE],"Ask")', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'es_historical_prices', 'bid_size', '=RTD("esrtd",,[CODE],"Bid Size")', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'es_historical_prices', 'ask_size', '=RTD("esrtd",,[CODE],"Ask Size")', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'es_historical_prices', 'open', '=RTD("esrtd",,[CODE],"Open")', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'es_historical_prices', 'high', '=RTD("esrtd",,[CODE],"High")', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'es_historical_prices', 'low', '=RTD("esrtd",,[CODE],"Low")', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'es_historical_prices', 'volume', '=RTD("esrtd",,[CODE],"Volume")', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'es_historical_prices', 'open_int', '=RTD("esrtd",,[CODE],"OpenInt")', NULL);

CREATE TABLE IF NOT EXISTS es_last_stock_quotes (
    symbol varchar(50) NOT NULL,
    date date NULL,
    time time NULL,
    last double NULL,
    change double NULL,
    percent_change double NULL,
    bid double NULL,
    ask double NULL,
    bid_size integer NULL,
    ask_size integer NULL,
    open double NULL,
    high double NULL,
    low double NULL,
    volume bigint NULL,
    open_int integer NULL,
    trade_price double NULL,
    last_update_timestamp timestamp default current_timestamp,
  PRIMARY KEY (symbol)
);


INSERT INTO real_time_tables (table_schema, table_name, load_code, is_history, is_disabled, time_zone, rtd_instance_name) VALUES (NULL, 'es_last_stock_quotes', 'SELECT code FROM es_stock_list', NULL, 1, 'Eastern Standard Time', NULL);

INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'es_last_stock_quotes', 'code', NULL, NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'es_last_stock_quotes', 'symbol', '=RTD("esrtd",,[CODE],"Symbol")', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'es_last_stock_quotes', 'date', '=Date()', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'es_last_stock_quotes', 'time', '=RTD("esrtd",,[CODE],"Time")', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'es_last_stock_quotes', 'last', '=RTD("esrtd",,[CODE],"Last")', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'es_last_stock_quotes', 'trade_price', '=RTD("esrtd",,[CODE],"TradePrice")', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'es_last_stock_quotes', 'change', '=RTD("esrtd",,[CODE],"Change")', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'es_last_stock_quotes', 'percent_change', '=RTD("esrtd",,[CODE],"% Change")', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'es_last_stock_quotes', 'bid', '=RTD("esrtd",,[CODE],"Bid")', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'es_last_stock_quotes', 'ask', '=RTD("esrtd",,[CODE],"Ask")', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'es_last_stock_quotes', 'bid_size', '=RTD("esrtd",,[CODE],"Bid Size")', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'es_last_stock_quotes', 'ask_size', '=RTD("esrtd",,[CODE],"Ask Size")', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'es_last_stock_quotes', 'open', '=RTD("esrtd",,[CODE],"Open")', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'es_last_stock_quotes', 'high', '=RTD("esrtd",,[CODE],"High")', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'es_last_stock_quotes', 'low', '=RTD("esrtd",,[CODE],"Low")', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'es_last_stock_quotes', 'volume', '=RTD("esrtd",,[CODE],"Volume")', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'es_last_stock_quotes', 'open_int', '=RTD("esrtd",,[CODE],"OpenInt")', NULL);

CREATE TABLE IF NOT EXISTS es_stock_quotes_ticks (
    id integer NOT NULL PRIMARY KEY AUTOINCREMENT,
    symbol varchar(50) NOT NULL,
    date date NULL,
    time time NULL,
    last double NULL,
    change double NULL,
    percent_change double NULL,
    bid double NULL,
    ask double NULL,
    bid_size integer NULL,
    ask_size integer NULL,
    open double NULL,
    high double NULL,
    low double NULL,
    volume bigint NULL,
    open_int integer NULL,
    trade_price double NULL
);

INSERT INTO real_time_tables (table_schema, table_name, load_code, is_history, is_disabled, time_zone, rtd_instance_name) VALUES (NULL, 'es_stock_quotes_ticks', 'SELECT code FROM es_stock_list', 1, 1, 'Eastern Standard Time', NULL);

INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'es_stock_quotes_ticks', 'id', NULL, NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'es_stock_quotes_ticks', 'code', NULL, NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'es_stock_quotes_ticks', 'symbol', '=RTD("esrtd",,[CODE],"Symbol")', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'es_stock_quotes_ticks', 'date', '=Date()', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'es_stock_quotes_ticks', 'time', '=RTD("esrtd",,[CODE],"Time")', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'es_stock_quotes_ticks', 'last', '=RTD("esrtd",,[CODE],"Last")', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'es_stock_quotes_ticks', 'trade_price', '=RTD("esrtd",,[CODE],"TradePrice")', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'es_stock_quotes_ticks', 'change', '=RTD("esrtd",,[CODE],"Change")', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'es_stock_quotes_ticks', 'percent_change', '=RTD("esrtd",,[CODE],"% Change")', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'es_stock_quotes_ticks', 'bid', '=RTD("esrtd",,[CODE],"Bid")', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'es_stock_quotes_ticks', 'ask', '=RTD("esrtd",,[CODE],"Ask")', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'es_stock_quotes_ticks', 'bid_size', '=RTD("esrtd",,[CODE],"Bid Size")', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'es_stock_quotes_ticks', 'ask_size', '=RTD("esrtd",,[CODE],"Ask Size")', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'es_stock_quotes_ticks', 'open', '=RTD("esrtd",,[CODE],"Open")', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'es_stock_quotes_ticks', 'high', '=RTD("esrtd",,[CODE],"High")', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'es_stock_quotes_ticks', 'low', '=RTD("esrtd",,[CODE],"Low")', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'es_stock_quotes_ticks', 'volume', '=RTD("esrtd",,[CODE],"Volume")', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'es_stock_quotes_ticks', 'open_int', '=RTD("esrtd",,[CODE],"OpenInt")', NULL);

CREATE TABLE IF NOT EXISTS es_stock_quotes_time (
    symbol varchar(50) NOT NULL,
    date date NOT NULL,
    time time NOT NULL,
    last double NULL,
    change double NULL,
    percent_change double NULL,
    bid double NULL,
    ask double NULL,
    bid_size integer NULL,
    ask_size integer NULL,
    open double NULL,
    high double NULL,
    low double NULL,
    volume bigint NULL,
    open_int integer NULL,
    trade_price double NULL,
    last_update_timestamp timestamp default current_timestamp,
  PRIMARY KEY (symbol, date, time)
);

INSERT INTO real_time_tables (table_schema, table_name, load_code, is_history, is_disabled, time_zone, rtd_instance_name) VALUES (NULL, 'es_stock_quotes_time', 'SELECT code FROM es_stock_list', NULL, 1, 'Eastern Standard Time', NULL);

INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'es_stock_quotes_time', 'code', NULL, NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'es_stock_quotes_time', 'symbol', '=RTD("esrtd",,[CODE],"Symbol")', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'es_stock_quotes_time', 'date', '=Date()', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'es_stock_quotes_time', 'time', '=RTD("esrtd",,[CODE],"Time")', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'es_stock_quotes_time', 'last', '=RTD("esrtd",,[CODE],"Last")', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'es_stock_quotes_time', 'trade_price', '=RTD("esrtd",,[CODE],"TradePrice")', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'es_stock_quotes_time', 'change', '=RTD("esrtd",,[CODE],"Change")', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'es_stock_quotes_time', 'percent_change', '=RTD("esrtd",,[CODE],"% Change")', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'es_stock_quotes_time', 'bid', '=RTD("esrtd",,[CODE],"Bid")', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'es_stock_quotes_time', 'ask', '=RTD("esrtd",,[CODE],"Ask")', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'es_stock_quotes_time', 'bid_size', '=RTD("esrtd",,[CODE],"Bid Size")', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'es_stock_quotes_time', 'ask_size', '=RTD("esrtd",,[CODE],"Ask Size")', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'es_stock_quotes_time', 'open', '=RTD("esrtd",,[CODE],"Open")', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'es_stock_quotes_time', 'high', '=RTD("esrtd",,[CODE],"High")', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'es_stock_quotes_time', 'low', '=RTD("esrtd",,[CODE],"Low")', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'es_stock_quotes_time', 'volume', '=RTD("esrtd",,[CODE],"Volume")', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'es_stock_quotes_time', 'open_int', '=RTD("esrtd",,[CODE],"OpenInt")', NULL);

